import 'dart:convert';
import 'dart:ui';

import 'package:flutter/cupertino.dart';

import 'modules/index.dart';
import 'types.dart' show IPropQueryable, ModuleBase, StringLocaleExtensions;

/// 翻译字典
class FTrKeybook implements IPropQueryable {
  FTrKeybook._(
    this.locale, {
    required this.auth,
    required this.bodyParts,
    required this.common,
    required this.homePage,
    required this.remedical,
    required this.profileComplete,
    required this.setting,
    required this.user,
    required this.organization,
    required this.measure,
    required this.upload,
  });

  /// 当前是否中文
  bool get isCurrentChinese => locale.languageCode.toLowerCase() == "zh";

  /// 字典语言
  final Locale locale;

  /// 授权模块
  final AuthModule auth;

  /// 身体部位模块
  final BodyPartsModule bodyParts;

  /// 首页模块
  final HomePageModule homePage;

  /// 公共模块
  final CommonModule common;

  /// 用户资料完善模块
  final ProfileCompleteModule profileComplete;

  /// 设置模块
  final SettingModule setting;

  /// 用户模块
  final UserModule user;

  /// 诊断模块
  final RemedicalModule remedical;

  // 组织模块
  final OrganizationModule organization;

  // 测量模块
  final MeasureModule measure;

  // 上传模块
  final UploadModule upload;

  /// 翻译字典 - 通过JsonMap构造
  ///
  /// [locale] 语言
  ///
  /// [map] 字典集
  factory FTrKeybook(Locale locale, dynamic map) {
    if (map == null || !(map is Map<String, dynamic>))
      throw ArgumentError(
          "FTrKeybook .ctor: argument-map must be a not null Map<String, dynamic>.");

    return FTrKeybook._(locale,
        auth: map.pick(AuthModule.ModuleName, (v) => AuthModule(v)),
        bodyParts:
            map.pick(BodyPartsModule.ModuleName, (v) => BodyPartsModule(v)),
        common: map.pick(CommonModule.ModuleName, (v) => CommonModule(v)),
        homePage: map.pick(HomePageModule.ModuleName, (v) => HomePageModule(v)),
        profileComplete: map.pick(
            ProfileCompleteModule.ModuleName, (v) => ProfileCompleteModule(v)),
        setting: map.pick(SettingModule.ModuleName, (v) => SettingModule(v)),
        user: map.pick(UserModule.ModuleName, (v) => UserModule(v)),
        remedical:
            map.pick(RemedicalModule.ModuleName, (v) => RemedicalModule(v)),
        organization: map.pick(
            OrganizationModule.ModuleName, (v) => OrganizationModule(v)),
        measure: map.pick(MeasureModule.ModuleName, (v) => MeasureModule(v)),
        upload: map.pick(UploadModule.ModuleName, (v) => UploadModule(v)));
  }

  /// 通过json字符串构造创建字典
  static FTrKeybook createFromJson(String text) {
    final map = jsonDecode(text);
    final localeStr = map['locale'];
    if (localeStr == null)
      throw ArgumentError(
          "FTrKeybook: create from json error - item `locale` is not defined.");
    final locale = (localeStr as String).toLocale();
    if (locale == null)
      throw ArgumentError(
          "FTrKeybook: create from json error - item `locale` is not valid.");
    return FTrKeybook(locale, map);
  }

  @override
  getProp(String propName) {
    switch (propName) {
      case AuthModule.ModuleName:
        return auth;
      case CommonModule.ModuleName:
        return common;
    }
    return null;
  }
}

typedef T _ModuleBuilder<T>(Map<String, dynamic> v);

extension _TrMapPickExtension on Map<String, dynamic> {
  /// 剥取翻译值
  ///
  /// [key] 字典键
  ///
  /// [defaultValue] 默认翻译
  T pick<T extends ModuleBase>(String key, _ModuleBuilder<T> builder) {
    dynamic value = this[key];
    if (value == null || !(value is Map<String, dynamic>))
      throw UnimplementedError(
          'translation keybook is not complete: Module - $key.');
    return builder(value);
  }
}
