import 'dart:ui';

import 'package:fis_i18n/types.dart';

import '../key_book.dart';

class CommonModule implements IPropQueryable {
  const CommonModule({
    required this.submit,
    required this.cancel,
    required this.search,
    required this.open,
    required this.email,
    required this.mobilePhoneNumber,
    required this.createTime,
    required this.refresh,
    required this.filtrate,
    required this.status,
    required this.waiting,
    required this.loading,
    required this.finish,
    required this.forward,
  });

  final String submit;
  final String cancel;
  final String search;
  final String open;
  final String email;
  final String mobilePhoneNumber;
  final String createTime;
  final String refresh;
  final String filtrate;
  final String status;
  final String waiting;
  final String loading;
  final String finish;
  final String forward;

  @override
  getProp(String propName) {
    if (propName == 'loading') {
      return this.loading;
    }
    throw ArgumentError('propery not found.');
  }

  @override
  Map<String, dynamic> toJson() {
    return {};
  }
}

/// 应用相关模块
class ApplicationModule {
  const ApplicationModule({
    required this.fisServerName,
    required this.wechat,
    required this.cloudImage,
    required this.localScreenshot,
    required this.report,
  });

  final String fisServerName;
  final String wechat;
  final String cloudImage;
  final String localScreenshot;
  final String report;
}

/// 诊断相关模块
class RemedicalModule {
  const RemedicalModule({
    required this.patientName,
    required this.patientFrom,
    required this.ultrasoundReport,
    required this.abdomen,
  });

  final String patientName;
  final String patientFrom;
  final String ultrasoundReport;
  final String abdomen;
}

/// 路由模块
class RouteModule {
  const RouteModule({
    required this.home,
    required this.contact,
    required this.conversation,
    required this.remedical,
    required this.course,
    required this.statistics,
    required this.setting,
    required this.btnDemo,
  });

  final String home;
  final String contact;
  final String conversation;
  final String remedical;
  final String course;
  final String statistics;
  final String setting;
  final String btnDemo;
}

class FLangKeyBookEnglish {
  static const LocaleConst = const Locale("en", "US");

  @override
  CommonModule buildCommonKeys() {
    return CommonModule(
      cancel: "Cancel",
      submit: "Submit",
      email: 'Email',
      mobilePhoneNumber: 'PhoneNumber',
      open: 'Open',
      search: 'Search',
      createTime: 'CreateTime',
      filtrate: 'Filtrate',
      finish: 'Finish',
      forward: 'Forward',
      refresh: 'Refresh',
      status: 'Status',
      waiting: 'Waiting...',
      loading: 'Loading...',
    );
  }

  @override
  ApplicationModule buildApplicationKeys() {
    return ApplicationModule(
      fisServerName: "Flyinsono server",
      wechat: "WeChat",
      cloudImage: 'Cloud images',
      localScreenshot: 'Local screenshots',
      report: 'Report',
    );
  }

  // @override
  // StateModule buildStateKeys() {
  //   return StateModule(
  //     finished: "Finished",
  //     unhandled: "Unhandled",
  //   );
  // }

  @override
  RemedicalModule buildRemedicalKeys() {
    return RemedicalModule(
      patientName: "Ptient name",
      patientFrom: "From",
      ultrasoundReport: "Ultrasound report",
      abdomen: "Abdomen",
    );
  }

  @override
  RouteModule buildRouteKeys() {
    return RouteModule(
      home: "Home",
      contact: "Contact",
      conversation: "Conversation",
      remedical: "Remedical",
      course: "Course",
      statistics: "Statistics",
      setting: "Setting",
      btnDemo: "ButtonDemo",
    );
  }
}
