import 'dart:ui';

import 'package:fis_i18n/types.dart';

import '../key_book.dart';

class CommonModule implements IPropQueryable {
  const CommonModule({
    required this.submit,
    required this.cancel,
    required this.search,
    required this.open,
    required this.email,
    required this.mobilePhoneNumber,
    required this.createTime,
    required this.refresh,
    required this.filtrate,
    required this.status,
    required this.waiting,
    required this.loading,
    required this.finish,
    required this.forward,
  });

  final String submit;
  final String cancel;
  final String search;
  final String open;
  final String email;
  final String mobilePhoneNumber;
  final String createTime;
  final String refresh;
  final String filtrate;
  final String status;
  final String waiting;
  final String loading;
  final String finish;
  final String forward;

  @override
  getProp(String propName) {
    if (propName == 'loading') {
      return this.loading;
    }
    throw ArgumentError('propery not found.');
  }

  @override
  Map<String, dynamic> toJson() {
    return {};
  }
}

/// 应用相关模块
class ApplicationModule {
  const ApplicationModule({
    required this.fisServerName,
    required this.wechat,
    required this.cloudImage,
    required this.localScreenshot,
    required this.report,
  });

  final String fisServerName;
  final String wechat;
  final String cloudImage;
  final String localScreenshot;
  final String report;
}

/// 诊断相关模块
class RemedicalModule {
  const RemedicalModule({
    required this.patientName,
    required this.patientFrom,
    required this.ultrasoundReport,
    required this.abdomen,
  });

  final String patientName;
  final String patientFrom;
  final String ultrasoundReport;
  final String abdomen;
}

/// 路由模块
class RouteModule {
  const RouteModule({
    required this.home,
    required this.contact,
    required this.conversation,
    required this.remedical,
    required this.course,
    required this.statistics,
    required this.setting,
    required this.btnDemo,
  });

  final String home;
  final String contact;
  final String conversation;
  final String remedical;
  final String course;
  final String statistics;
  final String setting;
  final String btnDemo;
}

class FLangKeyBookChinese {
  static const LocaleConst = const Locale("zh", "CN");

  @override
  CommonModule buildCommonKeys() {
    return CommonModule(
      cancel: "取消",
      submit: "提交",
      email: '邮箱',
      mobilePhoneNumber: '手机号',
      open: '打开',
      search: '搜索',
      createTime: '创建时间',
      filtrate: '筛选',
      finish: '完成',
      forward: '转发',
      refresh: '刷新',
      status: '状态',
      waiting: '等待中...',
      loading: '加载中...',
    );
  }

  @override
  ApplicationModule buildApplicationKeys() {
    return ApplicationModule(
      fisServerName: "杏聆荟服务器",
      wechat: "微信",
      cloudImage: '云端图像',
      localScreenshot: '本地截图',
      report: '报告',
    );
  }

  // @override
  // StateModule buildStateKeys() {
  //   return StateModule(
  //     finished: "已完成",
  //     unhandled: "未处理",
  //   );
  // }

  @override
  RemedicalModule buildRemedicalKeys() {
    return RemedicalModule(
      patientName: "病人名",
      patientFrom: "来自于",
      ultrasoundReport: "超声报告",
      abdomen: "腹部",
    );
  }

  @override
  RouteModule buildRouteKeys() {
    return RouteModule(
      home: "首页",
      contact: "联系人",
      conversation: "会话",
      remedical: "诊断",
      course: "课程",
      statistics: "统计",
      setting: "设置",
      btnDemo: "按钮",
    );
  }
}
